@@ -27,6 +27,7 @@ grid_options_defaults_dict = {
     "parse_function": None,  # FUnction to parse the output with.
     "tmp_dir": temp_dir(),  # Setting the temp dir of the program
     "_main_pid": -1,  # Placeholder for the main process id of the run.
+    "combine_ensemble_with_thread_joining": True,  # Flag on whether to combine everything and return it to the user or if false: write it to data_dir/ensemble_output_{popuation_id}_{thread_id}.json
     # "output_dir":
     "_commandline_input": "",
     ##########################
@@ -72,25 +73,20 @@ grid_options_defaults_dict = {
     # Population evolution
     ##########################
     ## General
-    "evolution_type": "mp",  # Flag for type of population evolution
+    "evolution_type": "grid",  # Flag for type of population evolution
     "_evolution_type_options": [
-        "mp",
-        "linear",
-    ],  # available choices for type of population evolution
+        "grid",
+    ],  # available choices for type of population evolution. # TODO: fill later with monte carlo, sourcefile
     "_system_generator": None,  # value that holds the function that generates the system
     # (result of building the grid script)
-    "population_type": "grid",  #
-    "_population_type_options": [
-        "grid",
-        "source_file",
-    ],  # Available choices for type of population generation. Unused for now. # TODO: fill later with monte carlo etc
     "source_file_filename": None,  # filename for the source
     "_count": 0,  # count of systems
     "_total_starcount": 0,  # Total count of systems in this generator
     "_probtot": 0,  # total probability
-    "_weight": 1.0,  # weighting for the probability
-    "_repeat": 1.0,  # number of times to repeat each system (probability is adjusted to be 1/repeat)
+    "weight": 1.0,  # weighting for the probability
+    "repeat": 1,  # number of times to repeat each system (probability is adjusted to be 1/repeat)
     "results": {},  # dict to store the results. Every process fills this on its own and then it will be joined later
+    "ensemble_results": {},  # Dict to store the ensemble results
     "_start_time_evolution": 0,  # Start time of the grid
     "_end_time_evolution": 0,  # end time of the grid
     "_errors_found": False,  # Flag whether there are any errors from binary_c
@@ -135,43 +131,43 @@ grid_options_defaults_dict = {
     # Slurm stuff
     ########################################
     "slurm": 0,  # dont use the slurm by default. 1 = use slurm
-    "slurm_ntasks": 1,  # CPUs required per array job: usually only need this
-    "slurm_command": "",  # Command that slurm runs (e.g. evolve or join_datafiles)
-    "slurm_dir": "",  # working directory containing scripts output logs etc.
-    "slurm_njobs": 0,  # number of scripts; set to 0 as default
-    "slurm_jobid": "",  # slurm job id (%A)
-    "slurm_memory": 512,  # in MB, the memory use of the job
-    "slurm_warn_max_memory": 1024,  # in MB : warn if mem req. > this
-    "slurm_use_all_node_CPUs": 0,  # 1 = use all of a node's CPUs. 0 = use a given amount of CPUs
-    "slurm_postpone_join": 0,  # if 1 do not join on slurm, join elsewhere. want to do it off the slurm grid (e.g. with more RAM)
-    "slurm_jobarrayindex": "",  # slurm job array index (%a)
-    "slurm_jobname": "binary_grid",  # default
-    "slurm_partition": None,
-    "slurm_time": 0,  # total time. 0 = infinite time
-    "slurm_postpone_sbatch": 0,  # if 1: don't submit, just make the script
-    "slurm_array": None,  # override for --array, useful for rerunning jobs
-    "slurm_use_all_node_CPUs": 0,  # if given nodes, set to 1
-    # if given CPUs, set to 0
-    # you will want to use this if your Slurm SelectType is e.g. linear
-    # which means it allocates all the CPUs in a node to the job
-    "slurm_control_CPUs": 0,  # if so, leave this many for Pythons control (0)
-    "slurm_array": None,  # override for --array, useful for rerunning jobs
-    "slurm_partition": None,  # MUST be defined
-    "slurm_extra_settings": {},  # Place to put extra configuration for the SLURM batch file. The key and value of the dict will become the key and value of the line in te slurm batch file. Will be put in after all the other settings (and before the command). Take care not to overwrite something without really meaning to do so.
+    # "slurm_ntasks": 1,  # CPUs required per array job: usually only need this
+    # "slurm_command": "",  # Command that slurm runs (e.g. evolve or join_datafiles)
+    # "slurm_dir": "",  # working directory containing scripts output logs etc.
+    # "slurm_njobs": 0,  # number of scripts; set to 0 as default
+    # "slurm_jobid": "",  # slurm job id (%A)
+    # "slurm_memory": 512,  # in MB, the memory use of the job
+    # "slurm_warn_max_memory": 1024,  # in MB : warn if mem req. > this
+    # "slurm_use_all_node_CPUs": 0,  # 1 = use all of a node's CPUs. 0 = use a given amount of CPUs
+    # "slurm_postpone_join": 0,  # if 1 do not join on slurm, join elsewhere. want to do it off the slurm grid (e.g. with more RAM)
+    # "slurm_jobarrayindex": "",  # slurm job array index (%a)
+    # "slurm_jobname": "binary_grid",  # default
+    # "slurm_partition": None,
+    # "slurm_time": 0,  # total time. 0 = infinite time
+    # "slurm_postpone_sbatch": 0,  # if 1: don't submit, just make the script
+    # "slurm_array": None,  # override for --array, useful for rerunning jobs
+    # "slurm_use_all_node_CPUs": 0,  # if given nodes, set to 1
+    # # if given CPUs, set to 0
+    # # you will want to use this if your Slurm SelectType is e.g. linear
+    # # which means it allocates all the CPUs in a node to the job
+    # "slurm_control_CPUs": 0,  # if so, leave this many for Pythons control (0)
+    # "slurm_array": None,  # override for --array, useful for rerunning jobs
+    # "slurm_partition": None,  # MUST be defined
+    # "slurm_extra_settings": {},  # Place to put extra configuration for the SLURM batch file. The key and value of the dict will become the key and value of the line in te slurm batch file. Will be put in after all the other settings (and before the command). Take care not to overwrite something without really meaning to do so.
     ########################################
     # Condor stuff
     ########################################
     "condor": 0,  # 1 to use condor, 0 otherwise
-    "condor_command": "",  # condor command e.g. "evolve", "join"
-    "condor_dir": "",  # working directory containing e.g. scripts, output, logs (e.g. should be NFS available to all)
-    "condor_njobs": "",  # number of scripts/jobs that CONDOR will run in total
-    "condor_jobid": "",  # condor job id
-    "condor_postpone_join": 0,  # if 1, data is not joined, e.g. if you want to do it off the condor grid (e.g. with more RAM)
-    # "condor_join_machine": None, # if defined then this is the machine on which the join command should be launched (must be sshable and not postponed)
-    "condor_join_pwd": "",  # directory the join should be in (defaults to $ENV{PWD} if undef)
-    "condor_memory": 1024,  # in MB, the memory use (ImageSize) of the job
-    "condor_universe": "vanilla",  # usually vanilla universe
-    "condor_extra_settings": {},  # Place to put extra configuration for the CONDOR submit file. The key and value of the dict will become the key and value of the line in te slurm batch file. Will be put in after all the other settings (and before the command). Take care not to overwrite something without really meaning to do so.
+    # "condor_command": "",  # condor command e.g. "evolve", "join"
+    # "condor_dir": "",  # working directory containing e.g. scripts, output, logs (e.g. should be NFS available to all)
+    # "condor_njobs": "",  # number of scripts/jobs that CONDOR will run in total
+    # "condor_jobid": "",  # condor job id
+    # "condor_postpone_join": 0,  # if 1, data is not joined, e.g. if you want to do it off the condor grid (e.g. with more RAM)
+    # # "condor_join_machine": None, # if defined then this is the machine on which the join command should be launched (must be sshable and not postponed)
+    # "condor_join_pwd": "",  # directory the join should be in (defaults to $ENV{PWD} if undef)
+    # "condor_memory": 1024,  # in MB, the memory use (ImageSize) of the job
+    # "condor_universe": "vanilla",  # usually vanilla universe
+    # "condor_extra_settings": {},  # Place to put extra configuration for the CONDOR submit file. The key and value of the dict will become the key and value of the line in te slurm batch file. Will be put in after all the other settings (and before the command). Take care not to overwrite something without really meaning to do so.
     # snapshots and checkpoints
     # condor_snapshot_on_kill=>0, # if 1 snapshot on SIGKILL before exit
     # condor_load_from_snapshot=>0, # if 1 check for snapshot .sv file and load it if found
@@ -462,13 +458,13 @@ grid_options_descriptions = {
     "_store_memaddr": "Memory adress of the store object for binary_c.",
     "failed_systems_threshold": "Variable storing the maximum amount of systems that are allowed to fail before logging their commandline arguments to failed_systems log files",
     "parse_function": "Function that the user can provide to handle the output the binary_c. This function has to take the arguments (self, output). Its best not to return anything in this function, and just store stuff in the grid_options['results'] dictionary, or just output results to a file",
-    "condor": "Int flag whether to use a condor type population evolution.",  # TODO: describe this in more detail
+    "condor": "Int flag whether to use a condor type population evolution. Not implemented yet.",  # TODO: describe this in more detail
     "slurm": "Int flag whether to use a slurm type population evolution.",  # TODO: describe this in more detail
-    "population_type": "variable storing what kind of population type should be evolved. See population_type_options for the options.",  # TODO: make this functionality work properly
-    "_population_type_options": "List storing the population_type options.",
-    "_weight": "Weight factor for each system. The calculated probability is mulitplied by this. If the user wants each system to be repeated several times, then this variable should not be changed, rather change the _repeat variable instead, as that handles the reduction in probability per system. This is useful for systems that have a process with some random element in it.",  # TODO: add more info here, regarding the evolution splitting.
-    "_repeat": "Factor of how many times a system should be repeated. Consider the evolution splitting binary_c argument for supernovae kick repeating.",  # TODO: make sure this is used.
+    "weight": "Weight factor for each system. The calculated probability is mulitplied by this. If the user wants each system to be repeated several times, then this variable should not be changed, rather change the _repeat variable instead, as that handles the reduction in probability per system. This is useful for systems that have a process with some random element in it.",  # TODO: add more info here, regarding the evolution splitting.
+    "repeat": "Factor of how many times a system should be repeated. Consider the evolution splitting binary_c argument for supernovae kick repeating.",  # TODO: make sure this is used.
     "evolution_type": "Variable containing the type of evolution used of the grid. Multiprocessing or linear processing",
+    "combine_ensemble_with_thread_joining": "BOolean flag on whether to combine everything and return it to the user or if false: write it to data_dir/ensemble_output_{popuation_id}_{thread_id}.json",
+    "ensemble_results": "Dictinary that stores the ensemble results if combine_ensemble_with_thread_joining==True",
 }
 
 #################################
